@@ -45,6 +45,7 @@
 #include <stdexcept>
 #include <numeric>  // for std::iota
 #include <algorithm>  // for std::sort
+#include <type_traits>  // for std::is_same_v
 
 // Make compilation fail - required for external projects - https://github.com/GUDHI/gudhi-devel/issues/10
 #if CGAL_VERSION_NR < 1041101000
@@ -97,7 +98,6 @@ template<typename D> struct Is_Epeck_D<CGAL::Epeck_d<D>> { static const bool val
  * [10^12,10^12+10^6]. Using `CGAL::Epick_d` makes the computations slightly faster, and the combinatorics are still
  * exact, but the computation of filtration values can exceptionally be arbitrarily bad. In all cases, we still
  * guarantee that the output is a valid filtration (faces have a filtration value no larger than their cofaces).
- * - For performances reasons, it is advised to use `Alpha_complex` with \ref cgal &ge; 5.0.0.
  */
 template<class Kernel = CGAL::Epeck_d<CGAL::Dynamic_dimension_tag>, bool Weighted = false>
 class Alpha_complex {
@@ -109,10 +109,15 @@ class Alpha_complex {
   /** \brief Geometric traits class that provides the geometric types and predicates needed by the triangulations.*/
   using Geom_traits = std::conditional_t<Weighted, CGAL::Regular_triangulation_traits_adapter<Kernel>, Kernel>;
 
+  // CGAL::Triangulation_ds_full_cell<void, CGAL::TDS_full_cell_mirror_storage_policy> has been enhanced for CGAL >= 6.0
+  // But faster only with static dimensions
+  using Triangulation_full_cell = std::conditional_t<std::is_same_v<typename Kernel::Dimension, CGAL::Dynamic_dimension_tag>,
+                                                     CGAL::Triangulation_ds_full_cell<>,
+                                                     CGAL::Triangulation_ds_full_cell<void, CGAL::TDS_full_cell_mirror_storage_policy>>;
   // Add an int in TDS to save point index in the structure
   using TDS = CGAL::Triangulation_data_structure<typename Geom_traits::Dimension,
                                                  CGAL::Triangulation_vertex<Geom_traits, Internal_vertex_handle>,
-                                                 CGAL::Triangulation_full_cell<Geom_traits> >;
+                                                 Triangulation_full_cell >;
 
   /** \brief A (Weighted or not) Delaunay triangulation of a set of points in \f$ \mathbb{R}^D\f$.*/
   using Triangulation = std::conditional_t<Weighted, CGAL::Regular_triangulation<Kernel, TDS>,
@@ -235,7 +240,9 @@ class Alpha_complex {
    * @exception std::out_of_range In case vertex is not found (cf. std::vector::at).
    */
   const Point_d& get_point(std::size_t vertex) const {
-    return vertex_handle_to_iterator_.at(vertex)->point();
+    auto it = vertex_handle_to_iterator_.at(vertex);
+    if (it == nullptr) throw std::out_of_range("This vertex is missing, maybe hidden by a duplicate or another heavier point.");
+    return it->point();
   }
 
  private:
@@ -248,8 +255,8 @@ class Alpha_complex {
     #endif
 
 #if CGAL_VERSION_NR < 1050101000
-    // Make compilation fail if weighted and CGAL < 5.1
-    static_assert(!Weighted, "Weighted Alpha_complex is only available for CGAL >= 5.1");
+    // Make compilation fail if weighted and CGAL < 5.1.0
+    static_assert(!Weighted, "Weighted Alpha_complex is only available for CGAL >= 5.1.0");
 #endif
 
     auto first = std::begin(points);
@@ -373,6 +380,11 @@ class Alpha_complex {
                       Filtration_value max_alpha_square = std::numeric_limits<Filtration_value>::infinity(),
                       bool exact = false,
                       bool default_filtration_value = false) {
+    // Filtration_value must be capable to represent the special value "Not-A-Number"
+    static_assert(std::numeric_limits<Filtration_value>::has_quiet_NaN);
+    // To support more general types for Filtration_value
+    using std::isnan;
+
     // From SimplicialComplexForAlpha type required to insert into a simplicial complex (with or without subfaces).
     using Vertex_handle = typename SimplicialComplexForAlpha::Vertex_handle;
     using Simplex_handle = typename SimplicialComplexForAlpha::Simplex_handle;
@@ -400,7 +412,7 @@ class Alpha_complex {
         std::clog << "SimplicialComplex insertion " << vertex << std::endl;
 #endif  // DEBUG_TRACES
         one_vertex[0] = vertex;
-        complex.insert_simplex_and_subfaces(one_vertex, std::numeric_limits<double>::quiet_NaN());
+        complex.insert_simplex_and_subfaces(one_vertex, std::numeric_limits<Filtration_value>::quiet_NaN());
       }
 
       for (auto cit = triangulation_->finite_full_cells_begin();
@@ -423,7 +435,7 @@ class Alpha_complex {
         std::clog << std::endl;
 #endif  // DEBUG_TRACES
         // Insert each simplex and its subfaces in the simplex tree - filtration is NaN
-        complex.insert_simplex_and_subfaces(vertexVector, std::numeric_limits<double>::quiet_NaN());
+        complex.insert_simplex_and_subfaces(vertexVector, std::numeric_limits<Filtration_value>::quiet_NaN());
       }
     }
     // --------------------------------------------------------------------------------------------
@@ -438,7 +450,7 @@ class Alpha_complex {
           int f_simplex_dim = complex.dimension(f_simplex);
           if (decr_dim == f_simplex_dim) {
             // ### If filt(Sigma) is NaN : filt(Sigma) = alpha(Sigma)
-            if (std::isnan(complex.filtration(f_simplex))) {
+            if (isnan(complex.filtration(f_simplex))) {
               Filtration_value alpha_complex_filtration = 0.0;
               // No need to compute squared_radius on a non-weighted single point - alpha is 0.0
               if (Weighted || f_simplex_dim > 0) {
@@ -480,6 +492,8 @@ class Alpha_complex {
   void propagate_alpha_filtration(SimplicialComplexForAlpha& complex, Simplex_handle f_simplex) {
     // From SimplicialComplexForAlpha type required to assign filtration values.
     using Filtration_value = typename SimplicialComplexForAlpha::Filtration_value;
+    // To support more general types for Filtration_value
+    using std::isnan;
 
     // ### Foreach Tau face of Sigma
     for (auto face_opposite_vertex : complex.boundary_opposite_vertex_simplex_range(f_simplex)) {
@@ -491,10 +505,10 @@ class Alpha_complex {
         std::clog << vertex << " ";
       }
       std::clog << "is a face of Sigma\n";
-      std::clog << " | isnan(complex.filtration(Tau)=" << std::isnan(complex.filtration(f_boundary)) << std::endl;
+      std::clog << " | isnan(complex.filtration(Tau)=" << isnan(complex.filtration(f_boundary)) << std::endl;
 #endif  // DEBUG_TRACES
       // ### If filt(Tau) is not NaN
-      if (!std::isnan(complex.filtration(f_boundary))) {
+      if (!isnan(complex.filtration(f_boundary))) {
         // ### filt(Tau) = fmin(filt(Tau), filt(Sigma))
         Filtration_value alpha_complex_filtration = fmin(complex.filtration(f_boundary),
                                                                              complex.filtration(f_simplex));
