@@ -12,6 +12,7 @@
 #define BITMAP_CUBICAL_COMPLEX_PERIODIC_BOUNDARY_CONDITIONS_BASE_H_
 
 #include <gudhi/Bitmap_cubical_complex_base.h>
+#include <gudhi/Debug_utils.h>
 
 #include <cmath>
 #include <limits>  // for numeric_limits<>
@@ -59,7 +60,7 @@ class Bitmap_cubical_complex_periodic_boundary_conditions_base : public Bitmap_c
    * A constructor of Bitmap_cubical_complex_periodic_boundary_conditions_base class that takes the name of Perseus
    * style file as an input. Please consult the documentation about the specification of the file.
    */
-  Bitmap_cubical_complex_periodic_boundary_conditions_base(const char* perseusStyleFile);
+  explicit Bitmap_cubical_complex_periodic_boundary_conditions_base(const char* perseusStyleFile);
   /**
    * A constructor of Bitmap_cubical_complex_periodic_boundary_conditions_base class that takes the following
    * parameters: (1) vector with numbers of top dimensional cells in all dimensions and (2) vector of top dimensional
@@ -68,8 +69,9 @@ class Bitmap_cubical_complex_periodic_boundary_conditions_base : public Bitmap_c
    * periodic boundary conditions will not be imposed in the direction i.
    */
   Bitmap_cubical_complex_periodic_boundary_conditions_base(
-      const std::vector<unsigned>& dimensions, const std::vector<T>& topDimensionalCells,
-      const std::vector<bool>& directions_in_which_periodic_b_cond_are_to_be_imposed);
+      const std::vector<unsigned>& dimensions, const std::vector<T>& cells,
+      const std::vector<bool>& directions_in_which_periodic_b_cond_are_to_be_imposed,
+      bool input_top_cells);
 
   /**
    * Destructor of the Bitmap_cubical_complex_periodic_boundary_conditions_base class.
@@ -149,10 +151,128 @@ class Bitmap_cubical_complex_periodic_boundary_conditions_base : public Bitmap_c
     return incidence;
   }
 
+  // The non-periodic code works for top dimensional cells, but not vertices.
+  class Vertices_iterator {
+   public:
+    typedef std::input_iterator_tag iterator_category;
+    typedef std::size_t value_type;
+    typedef std::ptrdiff_t difference_type;
+    typedef value_type* pointer;
+    typedef value_type reference;
+
+    Vertices_iterator(Bitmap_cubical_complex_periodic_boundary_conditions_base* b) : counter(b->dimension()), b(b) {}
+
+    Vertices_iterator operator++() {
+      // first find first element of the counter that can be increased:
+      std::size_t dim = 0;
+      while ((dim != this->b->dimension()) && (this->counter[dim] == this->b->sizes[dim] - this->b->directions_in_which_periodic_b_cond_are_to_be_imposed[dim])) ++dim;
+
+      if (dim != this->b->dimension()) {
+        ++this->counter[dim];
+        for (std::size_t i = 0; i != dim; ++i) {
+          this->counter[i] = 0;
+        }
+      } else {
+        ++this->counter[0];
+      }
+      return *this;
+    }
+
+    Vertices_iterator operator++(int) {
+      Vertices_iterator result = *this;
+      ++(*this);
+      return result;
+    }
+
+    bool operator==(const Vertices_iterator& rhs) const {
+      if (this->b != rhs.b) return false;
+      GUDHI_CHECK(this->counter.size() == rhs.counter.size(), "impossible");
+      for (std::size_t i = 0; i != this->counter.size(); ++i) {
+        if (this->counter[i] != rhs.counter[i]) return false;
+      }
+      return true;
+    }
+
+    bool operator!=(const Vertices_iterator& rhs) const { return !(*this == rhs); }
+
+    /*
+     * The operator * returns position of a cube in the structure of cubical complex. This position can be then used as
+     * an argument of the following functions:
+     * get_boundary_of_a_cell, get_coboundary_of_a_cell, get_dimension_of_a_cell to get information about the cell
+     * boundary and coboundary and dimension
+     * and in function get_cell_data to get a filtration of a cell.
+     */
+    std::size_t operator*() const { return this->compute_index_in_bitmap(); }
+
+    std::size_t compute_index_in_bitmap() const {
+      std::size_t index = 0;
+      for (std::size_t i = 0; i != this->counter.size(); ++i) {
+        index += 2 * this->counter[i] * this->b->multipliers[i];
+      }
+      return index;
+    }
+
+    void print_counter() const {
+      for (std::size_t i = 0; i != this->counter.size(); ++i) {
+        std::clog << this->counter[i] << " ";
+      }
+    }
+    friend class Bitmap_cubical_complex_periodic_boundary_conditions_base;
+
+   protected:
+    std::vector<std::size_t> counter;
+    Bitmap_cubical_complex_periodic_boundary_conditions_base* b;
+  };
+
+  /*
+   * Function returning a Vertices_iterator to the first vertex of the bitmap.
+   */
+  Vertices_iterator vertices_iterator_begin() {
+    Vertices_iterator a(this);
+    return a;
+  }
+
+  /*
+   * Function returning a Vertices_iterator to the last vertex of the bitmap.
+   */
+  Vertices_iterator vertices_iterator_end() {
+    Vertices_iterator a(this);
+    for (std::size_t i = 0; i != this->dimension(); ++i) {
+      a.counter[i] = this->sizes[i] - this->directions_in_which_periodic_b_cond_are_to_be_imposed[i];
+    }
+    a.counter[0]++;
+    return a;
+  }
+
+  /*
+   * @brief Vertices_iterator_range class provides ranges for Vertices_iterator_range
+   */
+  class Vertices_range {
+   public:
+    Vertices_range(Bitmap_cubical_complex_periodic_boundary_conditions_base* b) : b(b) {}
+
+    Vertices_iterator begin() { return b->vertices_iterator_begin(); }
+
+    Vertices_iterator end() { return b->vertices_iterator_end(); }
+
+   private:
+    Bitmap_cubical_complex_periodic_boundary_conditions_base* b;
+  };
+
+  /* Returns a range over all vertices. */
+  Vertices_range vertices_range() { return Vertices_range(this); }
+
+  /**
+   * Set cells filtrations given those of the vertices, and based on lower star filtration.
+   * This is already called by the relevant constructors.
+   **/
+  void impose_lower_star_filtration_from_vertices();
+
  protected:
   std::vector<bool> directions_in_which_periodic_b_cond_are_to_be_imposed;
 
-  void set_up_containers(const std::vector<unsigned>& sizes) {
+  void set_up_containers(const std::vector<unsigned>& sizes, bool is_pos_inf) {
+    // The fact that multipliers[0]=1 is relied on by optimizations in other functions
     unsigned multiplier = 1;
     for (std::size_t i = 0; i != sizes.size(); ++i) {
       this->sizes.push_back(sizes[i]);
@@ -165,19 +285,24 @@ class Bitmap_cubical_complex_periodic_boundary_conditions_base : public Bitmap_c
       }
     }
     // std::reverse( this->sizes.begin() , this->sizes.end() );
-    this->data = std::vector<T>(multiplier, std::numeric_limits<T>::infinity());
-    this->total_number_of_cells = multiplier;
+    if (is_pos_inf)
+      this->data = std::vector<T>(multiplier, std::numeric_limits<T>::infinity());
+    else
+      this->data = std::vector<T>(multiplier, -std::numeric_limits<T>::infinity());
   }
   Bitmap_cubical_complex_periodic_boundary_conditions_base(const std::vector<unsigned>& sizes);
   Bitmap_cubical_complex_periodic_boundary_conditions_base(const std::vector<unsigned>& dimensions,
-                                                           const std::vector<T>& topDimensionalCells);
+                                                           const std::vector<T>& cells,
+                                                           bool input_top_cells);
 
   /**
-   * A procedure used to construct the data structures in the class.
+   * Procedures used to construct the data structures in the class.
   **/
   void construct_complex_based_on_top_dimensional_cells(
       const std::vector<unsigned>& dimensions, const std::vector<T>& topDimensionalCells,
       const std::vector<bool>& directions_in_which_periodic_b_cond_are_to_be_imposed);
+  void construct_complex_based_on_vertices(const std::vector<unsigned>& dimensions, const std::vector<T>& vertices,
+      const std::vector<bool>& directions_in_which_periodic_b_cond_are_to_be_imposed);
 };
 
 template <typename T>
@@ -185,7 +310,7 @@ void Bitmap_cubical_complex_periodic_boundary_conditions_base<T>::construct_comp
     const std::vector<unsigned>& dimensions, const std::vector<T>& topDimensionalCells,
     const std::vector<bool>& directions_in_which_periodic_b_cond_are_to_be_imposed) {
   this->directions_in_which_periodic_b_cond_are_to_be_imposed = directions_in_which_periodic_b_cond_are_to_be_imposed;
-  this->set_up_containers(dimensions);
+  this->set_up_containers(dimensions, true);
 
   std::size_t i = 0;
   for (auto it = this->top_dimensional_cells_iterator_begin(); it != this->top_dimensional_cells_iterator_end(); ++it) {
@@ -195,22 +320,40 @@ void Bitmap_cubical_complex_periodic_boundary_conditions_base<T>::construct_comp
   this->impose_lower_star_filtration();
 }
 
+template <typename T>
+void Bitmap_cubical_complex_periodic_boundary_conditions_base<T>::construct_complex_based_on_vertices(
+    const std::vector<unsigned>& dimensions, const std::vector<T>& vertices,
+    const std::vector<bool>& directions_in_which_periodic_b_cond_are_to_be_imposed) {
+  this->directions_in_which_periodic_b_cond_are_to_be_imposed = directions_in_which_periodic_b_cond_are_to_be_imposed;
+
+  std::vector<unsigned> top_cells_sizes;
+  std::transform (dimensions.begin(), dimensions.end(), directions_in_which_periodic_b_cond_are_to_be_imposed.begin(),
+      std::back_inserter(top_cells_sizes), [](unsigned i, bool b){ return i - !b;});
+  this->set_up_containers(top_cells_sizes, false);
+
+  std::size_t i = 0;
+  for (auto it = this->vertices_iterator_begin(); it != this->vertices_iterator_end(); ++it) {
+    this->get_cell_data(*it) = vertices[i];
+    ++i;
+  }
+  this->impose_lower_star_filtration_from_vertices();
+}
+
 template <typename T>
 Bitmap_cubical_complex_periodic_boundary_conditions_base<T>::Bitmap_cubical_complex_periodic_boundary_conditions_base(
     const std::vector<unsigned>& sizes,
-    const std::vector<bool>& directions_in_which_periodic_b_cond_are_to_be_imposed) {
-  this->directions_in_which_periodic_b_cond_are_to_be_imposed(directions_in_which_periodic_b_cond_are_to_be_imposed);
-  this->set_up_containers(sizes);
+    const std::vector<bool>& directions_in_which_periodic_b_cond_are_to_be_imposed) 
+    : directions_in_which_periodic_b_cond_are_to_be_imposed(directions_in_which_periodic_b_cond_are_to_be_imposed) {
+  this->set_up_containers(sizes, true);
 }
 
 template <typename T>
 Bitmap_cubical_complex_periodic_boundary_conditions_base<T>::Bitmap_cubical_complex_periodic_boundary_conditions_base(
     const char* perseus_style_file) {
   // for Perseus style files:
-  bool dbg = false;
 
-  std::ifstream inFiltration;
-  inFiltration.open(perseus_style_file);
+  std::ifstream inFiltration(perseus_style_file);
+  if(!inFiltration) throw std::ios_base::failure(std::string("Could not open the file ") + perseus_style_file);
   unsigned dimensionOfData;
   inFiltration >> dimensionOfData;
 
@@ -226,9 +369,9 @@ Bitmap_cubical_complex_periodic_boundary_conditions_base<T>::Bitmap_cubical_comp
     }
     sizes.push_back(abs(size_in_this_dimension));
   }
-  this->set_up_containers(sizes);
+  this->set_up_containers(sizes, true);
 
-  typename Bitmap_cubical_complex_periodic_boundary_conditions_base<T>::Top_dimensional_cells_iterator it(*this);
+  typename Bitmap_cubical_complex_periodic_boundary_conditions_base<T>::Top_dimensional_cells_iterator
   it = this->top_dimensional_cells_iterator_begin();
 
   while (!inFiltration.eof()) {
@@ -236,11 +379,11 @@ Bitmap_cubical_complex_periodic_boundary_conditions_base<T>::Bitmap_cubical_comp
     inFiltration >> filtrationLevel;
     if (inFiltration.eof()) break;
 
-    if (dbg) {
-      std::clog << "Cell of an index : " << it.compute_index_in_bitmap()
-                << " and dimension: " << this->get_dimension_of_a_cell(it.compute_index_in_bitmap())
-                << " get the value : " << filtrationLevel << std::endl;
-    }
+#ifdef DEBUG_TRACES
+    std::clog << "Cell of an index : " << it.compute_index_in_bitmap()
+              << " and dimension: " << this->get_dimension_of_a_cell(it.compute_index_in_bitmap())
+              << " get the value : " << filtrationLevel << std::endl;
+#endif
     this->get_cell_data(*it) = filtrationLevel;
     ++it;
   }
@@ -252,23 +395,34 @@ template <typename T>
 Bitmap_cubical_complex_periodic_boundary_conditions_base<T>::Bitmap_cubical_complex_periodic_boundary_conditions_base(
     const std::vector<unsigned>& sizes) {
   this->directions_in_which_periodic_b_cond_are_to_be_imposed = std::vector<bool>(sizes.size(), false);
-  this->set_up_containers(sizes);
+  this->set_up_containers(sizes, true);
 }
 
 template <typename T>
 Bitmap_cubical_complex_periodic_boundary_conditions_base<T>::Bitmap_cubical_complex_periodic_boundary_conditions_base(
-    const std::vector<unsigned>& dimensions, const std::vector<T>& topDimensionalCells) {
+    const std::vector<unsigned>& dimensions, const std::vector<T>& cells, bool input_top_cells) {
   std::vector<bool> directions_in_which_periodic_b_cond_are_to_be_imposed = std::vector<bool>(dimensions.size(), false);
-  this->construct_complex_based_on_top_dimensional_cells(dimensions, topDimensionalCells,
-                                                         directions_in_which_periodic_b_cond_are_to_be_imposed);
+  if (input_top_cells) {
+    this->construct_complex_based_on_top_dimensional_cells(dimensions, cells,
+                                                           directions_in_which_periodic_b_cond_are_to_be_imposed);
+  } else {
+    this->construct_complex_based_on_vertices(dimensions, cells,
+                                              directions_in_which_periodic_b_cond_are_to_be_imposed);
+  }
 }
 
 template <typename T>
 Bitmap_cubical_complex_periodic_boundary_conditions_base<T>::Bitmap_cubical_complex_periodic_boundary_conditions_base(
-    const std::vector<unsigned>& dimensions, const std::vector<T>& topDimensionalCells,
-    const std::vector<bool>& directions_in_which_periodic_b_cond_are_to_be_imposed) {
-  this->construct_complex_based_on_top_dimensional_cells(dimensions, topDimensionalCells,
-                                                         directions_in_which_periodic_b_cond_are_to_be_imposed);
+    const std::vector<unsigned>& dimensions, const std::vector<T>& cells,
+    const std::vector<bool>& directions_in_which_periodic_b_cond_are_to_be_imposed,
+    bool input_top_cells) {
+  if(input_top_cells) {
+    this->construct_complex_based_on_top_dimensional_cells(dimensions, cells,
+                                                           directions_in_which_periodic_b_cond_are_to_be_imposed);
+  } else {
+    this->construct_complex_based_on_vertices(dimensions, cells,
+                                              directions_in_which_periodic_b_cond_are_to_be_imposed);
+  }
 }
 
 // ***********************Methods************************ //
@@ -276,10 +430,9 @@ Bitmap_cubical_complex_periodic_boundary_conditions_base<T>::Bitmap_cubical_comp
 template <typename T>
 std::vector<std::size_t> Bitmap_cubical_complex_periodic_boundary_conditions_base<T>::get_boundary_of_a_cell(
     std::size_t cell) const {
-  bool dbg = false;
-  if (dbg) {
-    std::clog << "Computations of boundary of a cell : " << cell << std::endl;
-  }
+#ifdef DEBUG_TRACES
+  std::clog << "Computations of boundary of a cell : " << cell << std::endl;
+#endif
 
   std::vector<std::size_t> boundary_elements;
   boundary_elements.reserve(this->dimension() * 2);
@@ -288,6 +441,7 @@ std::vector<std::size_t> Bitmap_cubical_complex_periodic_boundary_conditions_bas
 
   for (std::size_t i = this->multipliers.size(); i != 0; --i) {
     unsigned position = cell1 / this->multipliers[i - 1];
+    cell1 = cell1 % this->multipliers[i - 1];
     // this cell have a nonzero length in this direction, therefore we can compute its boundary in this direction.
     if (position % 2 == 1) {
       // if there are no periodic boundary conditions in this direction, we do not have to do anything.
@@ -299,9 +453,9 @@ std::vector<std::size_t> Bitmap_cubical_complex_periodic_boundary_conditions_bas
           boundary_elements.push_back(cell + this->multipliers[i - 1]);
           boundary_elements.push_back(cell - this->multipliers[i - 1]);
         }
-        if (dbg) {
-          std::clog << cell - this->multipliers[i - 1] << " " << cell + this->multipliers[i - 1] << " ";
-        }
+#ifdef DEBUG_TRACES
+        std::clog << cell - this->multipliers[i - 1] << " " << cell + this->multipliers[i - 1] << " ";
+#endif
       } else {
         // in this direction we have to do boundary conditions. Therefore, we need to check if we are not at the end.
         if (position != 2 * this->sizes[i - 1] - 1) {
@@ -312,9 +466,9 @@ std::vector<std::size_t> Bitmap_cubical_complex_periodic_boundary_conditions_bas
             boundary_elements.push_back(cell + this->multipliers[i - 1]);
             boundary_elements.push_back(cell - this->multipliers[i - 1]);
           }
-          if (dbg) {
-            std::clog << cell - this->multipliers[i - 1] << " " << cell + this->multipliers[i - 1] << " ";
-          }
+#ifdef DEBUG_TRACES
+          std::clog << cell - this->multipliers[i - 1] << " " << cell + this->multipliers[i - 1] << " ";
+#endif
         } else {
           if (sum_of_dimensions % 2) {
             boundary_elements.push_back(cell - this->multipliers[i - 1]);
@@ -323,15 +477,14 @@ std::vector<std::size_t> Bitmap_cubical_complex_periodic_boundary_conditions_bas
             boundary_elements.push_back(cell - (2 * this->sizes[i - 1] - 1) * this->multipliers[i - 1]);
             boundary_elements.push_back(cell - this->multipliers[i - 1]);
           }
-          if (dbg) {
-            std::clog << cell - this->multipliers[i - 1] << " "
-                      << cell - (2 * this->sizes[i - 1] - 1) * this->multipliers[i - 1] << " ";
-          }
+#ifdef DEBUG_TRACES
+          std::clog << cell - this->multipliers[i - 1] << " "
+                    << cell - (2 * this->sizes[i - 1] - 1) * this->multipliers[i - 1] << " ";
+#endif
         }
       }
       ++sum_of_dimensions;
     }
-    cell1 = cell1 % this->multipliers[i - 1];
   }
   return boundary_elements;
 }
@@ -344,6 +497,7 @@ std::vector<std::size_t> Bitmap_cubical_complex_periodic_boundary_conditions_bas
   std::size_t cell1 = cell;
   for (std::size_t i = this->multipliers.size(); i != 0; --i) {
     unsigned position = cell1 / this->multipliers[i - 1];
+    cell1 = cell1 % this->multipliers[i - 1];
     // if the cell has zero length in this direction, then it will have cbd in this direction.
     if (position % 2 == 0) {
       if (!this->directions_in_which_periodic_b_cond_are_to_be_imposed[i - 1]) {
@@ -366,12 +520,56 @@ std::vector<std::size_t> Bitmap_cubical_complex_periodic_boundary_conditions_bas
         }
       }
     }
-
-    cell1 = cell1 % this->multipliers[i - 1];
   }
   return coboundary_elements;
 }
 
+// Exact same code as the non-periodic version, duplicated for now to ensure it calls the right version of vertices_iterator_begin.
+template <typename T>
+void Bitmap_cubical_complex_periodic_boundary_conditions_base<T>::impose_lower_star_filtration_from_vertices() {
+  // this vector will be used to check which elements have already been taken care of in imposing lower star filtration
+  std::vector<bool> is_this_cell_considered(this->data.size(), false);
+
+  std::vector<std::size_t> indices_to_consider;
+  // we assume here that we already have a filtration on the vertices and
+  // we have to extend it to higher ones.
+  for (auto it = this->vertices_iterator_begin();
+       it != this->vertices_iterator_end(); ++it) {
+    indices_to_consider.push_back(it.compute_index_in_bitmap());
+  }
+
+  while (indices_to_consider.size()) { // Iteration on the dimension
+#ifdef DEBUG_TRACES
+    std::clog << "indices_to_consider in this iteration \n";
+    for (auto index : indices_to_consider) {
+      std::clog << index << "  ";
+    }
+#endif
+    std::vector<std::size_t> new_indices_to_consider;
+    for (auto index : indices_to_consider) {
+      std::vector<std::size_t> cbd = this->get_coboundary_of_a_cell(index);
+      for (auto coboundary : cbd) {
+#ifdef DEBUG_TRACES
+        std::clog << "filtration of a cell : " << coboundary << " is : " << this->data[coboundary]
+                  << " while of a cell: " << index << " is: " << this->data[index]
+                  << std::endl;
+#endif
+        if (this->data[coboundary] < this->data[index]) {
+          this->data[coboundary] = this->data[index];
+#ifdef DEBUG_TRACES
+          std::clog << "Setting the value of a cell : " << coboundary
+                    << " to : " << this->data[index] << std::endl;
+#endif
+        }
+        if (is_this_cell_considered[coboundary] == false) {
+          new_indices_to_consider.push_back(coboundary);
+          is_this_cell_considered[coboundary] = true;
+        }
+      }
+    }
+    indices_to_consider.swap(new_indices_to_consider);
+  }
+}
 }  // namespace cubical_complex
 
 namespace Cubical_complex = cubical_complex;
