@@ -17,19 +17,23 @@ import warnings
 
 def test_array_handler():
     diags = np.array([[1, 2], [3, 4], [5, 6]], float)
-    arr_diags = gd.persistence_graphical_tools._array_handler(diags)
+    arr_diags, nx2_array = gd.persistence_graphical_tools._array_handler(diags)
+    assert nx2_array
     for idx in range(len(diags)):
         assert arr_diags[idx][0] == 0
         np.testing.assert_array_equal(arr_diags[idx][1], diags[idx])
 
     diags = [(1.0, 2.0), (3.0, 4.0), (5.0, 6.0)]
-    arr_diags = gd.persistence_graphical_tools._array_handler(diags)
+    arr_diags, nx2_array = gd.persistence_graphical_tools._array_handler(diags)
+    assert nx2_array
     for idx in range(len(diags)):
         assert arr_diags[idx][0] == 0
         assert arr_diags[idx][1] == diags[idx]
 
     diags = [(0, (1.0, 2.0)), (0, (3.0, 4.0)), (0, (5.0, 6.0))]
-    assert gd.persistence_graphical_tools._array_handler(diags) == diags
+    arr_diags, nx2_array = gd.persistence_graphical_tools._array_handler(diags)
+    assert not nx2_array
+    assert arr_diags == diags
 
 
 def test_min_birth_max_death():
@@ -45,8 +49,8 @@ def test_min_birth_max_death():
         (0, (0.0, 0.107535)),
         (0, (0.0, 0.106382)),
     ]
-    assert gd.persistence_graphical_tools.__min_birth_max_death(diags) == (0.0, 1.0)
-    assert gd.persistence_graphical_tools.__min_birth_max_death(diags, band=4.0) == (0.0, 5.0)
+    assert gd.persistence_graphical_tools._min_birth_max_death(diags) == (0.0, 1.0)
+    assert gd.persistence_graphical_tools._min_birth_max_death(diags, band=4.0) == (0.0, 5.0)
 
 
 def test_limit_min_birth_max_death():
@@ -54,8 +58,8 @@ def test_limit_min_birth_max_death():
         (0, (2.0, float("inf"))),
         (0, (2.0, float("inf"))),
     ]
-    assert gd.persistence_graphical_tools.__min_birth_max_death(diags) == (2.0, 3.0)
-    assert gd.persistence_graphical_tools.__min_birth_max_death(diags, band=4.0) == (2.0, 6.0)
+    assert gd.persistence_graphical_tools._min_birth_max_death(diags) == (2.0, 3.0)
+    assert gd.persistence_graphical_tools._min_birth_max_death(diags, band=4.0) == (2.0, 6.0)
 
 
 def test_limit_to_max_intervals():
